Address

Struct Address 

pub struct Address {
    pub city: Option<String>,
    pub country: Option<String>,
    pub country_code: Option<String>,
    pub extended_address: Option<String>,
    pub formatted_type: Option<String>,
    pub formatted_value: Option<String>,
    pub metadata: Option<FieldMetadata>,
    pub po_box: Option<String>,
    pub postal_code: Option<String>,
    pub region: Option<String>,
    pub street_address: Option<String>,
    pub type_: Option<String>,
}
A person’s physical address. May be a P.O. box or street address. All fields are optional.

This type is not used in any activity, and only used as part of another schema.

Fields

city: Option<String>

The city of the address.

country: Option<String>

The country of the address.

country_code: Option<String>

The ISO 3166-1 alpha-2 country code of the address.

extended_address: Option<String>

The extended address of the address; for example, the apartment number.

formatted_type: Option<String>

Output only. The type of the address translated and formatted in the viewer’s account locale or the Accept-Language HTTP header locale.

formatted_value: Option<String>

The unstructured value of the address. If this is not set by the user it will be automatically constructed from structured values.

metadata: Option<FieldMetadata>

Metadata about the address.

po_box: Option<String>

The P.O. box of the address.

postal_code: Option<String>

The postal code of the address.

region: Option<String>

The region of the address; for example, the state or province.

street_address: Option<String>

The street address.

type_: Option<String>

The type of the address. The type can be custom or one of these predefined values: * home * work * other