pub struct BatchUpdateContactsResponse {
pub update_result: Option<HashMap<String, PersonResponse>>,
}Expand description
If not successful, returns BatchUpdateContactsErrorDetails, a list of errors corresponding to each contact. The response to a request to update a batch of contacts.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- batch update contacts people (response)
Fields
update_result: Option<HashMap<String, PersonResponse>>A map of resource names to the contacts that were updated, unless the request read_mask is empty.