ContactGroupMethods

Struct ContactGroupMethods 

pub struct ContactGroupMethods<'a, C>
where C: 'a,
{ /* private fields */ }
A builder providing access to all methods supported on contactGroup resources. It is not used directly, but through the PeopleService hub.

Example

Instantiate a resource builder

extern crate hyper;
extern crate hyper_rustls;
extern crate google_people1 as people1;

use people1::{PeopleService, FieldMask, hyper_rustls, hyper_util, yup_oauth2};

let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
    .with_native_roots()
    .unwrap()
    .https_only()
    .enable_http2()
    .build();

let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
    secret,
    yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
    yup_oauth2::client::CustomHyperClientBuilder::from(
        hyper_util::client::legacy::Client::builder(executor).build(connector),
    ),
).build().await.unwrap();

let client = hyper_util::client::legacy::Client::builder(
    hyper_util::rt::TokioExecutor::new()
)
.build(
    hyper_rustls::HttpsConnectorBuilder::new()
        .with_native_roots()
        .unwrap()
        .https_or_http()
        .enable_http2()
        .build()
);
let mut hub = PeopleService::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `batch_get(...)`, `create(...)`, `delete(...)`, `get(...)`, `list(...)`, `members_modify(...)` and `update(...)`
// to build up your call.
let rb = hub.contact_groups();

Implementations

Source

impl<'a, C> ContactGroupMethods<'a, C>

pub fn members_modify( &self, request: ModifyContactGroupMembersRequest, resource_name: &str, ) -> ContactGroupMemberModifyCall<'a, C>

Create a builder to help you perform the following task:

Modify the members of a contact group owned by the authenticated user. The only system contact groups that can have members added are contactGroups/myContacts and contactGroups/starred. Other system contact groups are deprecated and can only have contacts removed.

Arguments
  • request - No description provided.
  • resourceName - Required. The resource name of the contact group to modify.
pub fn batch_get(&self) -> ContactGroupBatchGetCall<'a, C>

Create a builder to help you perform the following task:

Get a list of contact groups owned by the authenticated user by specifying a list of contact group resource names.

pub fn create( &self, request: CreateContactGroupRequest, ) -> ContactGroupCreateCall<'a, C>

Create a builder to help you perform the following task:

Create a new contact group owned by the authenticated user. Created contact group names must be unique to the users contact groups. Attempting to create a group with a duplicate name will return a HTTP 409 error. Mutate requests for the same user should be sent sequentially to avoid increased latency and failures.

Arguments
  • request - No description provided.
pub fn delete(&self, resource_name: &str) -> ContactGroupDeleteCall<'a, C>

Create a builder to help you perform the following task:

Delete an existing contact group owned by the authenticated user by specifying a contact group resource name. Mutate requests for the same user should be sent sequentially to avoid increased latency and failures.

Arguments
  • resourceName - Required. The resource name of the contact group to delete.
pub fn get(&self, resource_name: &str) -> ContactGroupGetCall<'a, C>

Create a builder to help you perform the following task:

Get a specific contact group owned by the authenticated user by specifying a contact group resource name.

Arguments
  • resourceName - Required. The resource name of the contact group to get.
pub fn list(&self) -> ContactGroupListCall<'a, C>

Create a builder to help you perform the following task:

List all contact groups owned by the authenticated user. Members of the contact groups are not populated.

pub fn update( &self, request: UpdateContactGroupRequest, resource_name: &str, ) -> ContactGroupUpdateCall<'a, C>

Create a builder to help you perform the following task:

Update the name of an existing contact group owned by the authenticated user. Updated contact group names must be unique to the users contact groups. Attempting to create a group with a duplicate name will return a HTTP 409 error. Mutate requests for the same user should be sent sequentially to avoid increased latency and failures.

Arguments
  • request - No description provided.
  • resourceName - The resource name for the contact group, assigned by the server. An ASCII string, in the form of contactGroups/{contact_group_id}.