pub struct ContactToCreate {
pub contact_person: Option<Person>,
}Expand description
A wrapper that contains the person data to populate a newly created source.
This type is not used in any activity, and only used as part of another schema.
Fields
contact_person: Option<Person>Required. The person data to populate a newly created source.