pub struct Event {
pub date: Option<Date>,
pub formatted_type: Option<String>,
pub metadata: Option<FieldMetadata>,
pub type_: Option<String>,
}Expand description
An event related to the person.
This type is not used in any activity, and only used as part of another schema.
Fields
date: Option<Date>The date of the event.
formatted_type: Option<String>Output only. The type of the event translated and formatted in the viewer’s account locale or the Accept-Language HTTP header locale.
metadata: Option<FieldMetadata>Metadata about the event.
type_: Option<String>The type of the event. The type can be custom or one of these predefined values: * anniversary * other