pub struct FileAs {
pub metadata: Option<FieldMetadata>,
pub value: Option<String>,
}Expand description
The name that should be used to sort the person in a list.
This type is not used in any activity, and only used as part of another schema.
Fields
metadata: Option<FieldMetadata>Metadata about the file-as.
value: Option<String>The file-as value