pub struct ImClient {
pub formatted_protocol: Option<String>,
pub formatted_type: Option<String>,
pub metadata: Option<FieldMetadata>,
pub protocol: Option<String>,
pub type_: Option<String>,
pub username: Option<String>,
}Expand description
A person’s instant messaging client.
This type is not used in any activity, and only used as part of another schema.
Fields
formatted_protocol: Option<String>Output only. The protocol of the IM client formatted in the viewer’s account locale or the Accept-Language HTTP header locale.
formatted_type: Option<String>Output only. The type of the IM client translated and formatted in the viewer’s account locale or the Accept-Language HTTP header locale.
metadata: Option<FieldMetadata>Metadata about the IM client.
protocol: Option<String>The protocol of the IM client. The protocol can be custom or one of these predefined values: * aim * msn * yahoo * skype * qq * googleTalk * icq * jabber * netMeeting
type_: Option<String>The type of the IM client. The type can be custom or one of these predefined values: * home * work * other
username: Option<String>The user name used in the IM client.