pub struct OtherContactMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on otherContact resources.
It is not used directly, but through the PeopleService hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_people1 as people1;
use people1::{PeopleService, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = PeopleService::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `copy_other_contact_to_my_contacts_group(...)`, `list(...)` and `search(...)`
// to build up your call.
let rb = hub.other_contacts();Implementations
Sourceimpl<'a, C> OtherContactMethods<'a, C>
impl<'a, C> OtherContactMethods<'a, C>
Sourcepub fn copy_other_contact_to_my_contacts_group(
&self,
request: CopyOtherContactToMyContactsGroupRequest,
resource_name: &str,
) -> OtherContactCopyOtherContactToMyContactsGroupCall<'a, C>
pub fn copy_other_contact_to_my_contacts_group( &self, request: CopyOtherContactToMyContactsGroupRequest, resource_name: &str, ) -> OtherContactCopyOtherContactToMyContactsGroupCall<'a, C>
Create a builder to help you perform the following task:
Copies an “Other contact” to a new contact in the user’s “myContacts” group Mutate requests for the same user should be sent sequentially to avoid increased latency and failures.
Arguments
request- No description provided.resourceName- Required. The resource name of the “Other contact” to copy.
Sourcepub fn list(&self) -> OtherContactListCall<'a, C>
pub fn list(&self) -> OtherContactListCall<'a, C>
Create a builder to help you perform the following task:
List all “Other contacts”, that is contacts that are not in a contact group. “Other contacts” are typically auto created contacts from interactions. Sync tokens expire 7 days after the full sync. A request with an expired sync token will get an error with an google.rpc.ErrorInfo with reason “EXPIRED_SYNC_TOKEN”. In the case of such an error clients should make a full sync request without a sync_token. The first page of a full sync request has an additional quota. If the quota is exceeded, a 429 error will be returned. This quota is fixed and can not be increased. When the sync_token is specified, resources deleted since the last sync will be returned as a person with PersonMetadata.deleted set to true. When the page_token or sync_token is specified, all other request parameters must match the first call. Writes may have a propagation delay of several minutes for sync requests. Incremental syncs are not intended for read-after-write use cases. See example usage at List the user’s other contacts that have changed.
Sourcepub fn search(&self) -> OtherContactSearchCall<'a, C>
pub fn search(&self) -> OtherContactSearchCall<'a, C>
Create a builder to help you perform the following task:
Provides a list of contacts in the authenticated user’s other contacts that matches the search query. The query matches on a contact’s names, emailAddresses, and phoneNumbers fields that are from the OTHER_CONTACT source. IMPORTANT: Before searching, clients should send a warmup request with an empty query to update the cache. See https://developers.google.com/people/v1/other-contacts#search_the_users_other_contacts