pub struct Relation {
pub formatted_type: Option<String>,
pub metadata: Option<FieldMetadata>,
pub person: Option<String>,
pub type_: Option<String>,
}Expand description
A person’s relation to another person.
This type is not used in any activity, and only used as part of another schema.
Fields
formatted_type: Option<String>Output only. The type of the relation translated and formatted in the viewer’s account locale or the locale specified in the Accept-Language HTTP header.
metadata: Option<FieldMetadata>Metadata about the relation.
person: Option<String>The name of the other person this relation refers to.
type_: Option<String>The person’s relation to the other person. The type can be custom or one of these predefined values: * spouse * child * mother * father * parent * brother * sister * friend * relative * domesticPartner * manager * assistant * referredBy * partner