pub struct Source {
pub etag: Option<String>,
pub id: Option<String>,
pub profile_metadata: Option<ProfileMetadata>,
pub type_: Option<String>,
pub update_time: Option<DateTime<Utc>>,
}Expand description
The source of a field.
This type is not used in any activity, and only used as part of another schema.
Fields
etag: Option<String>Only populated in person.metadata.sources. The HTTP entity tag of the source. Used for web cache validation.
id: Option<String>The unique identifier within the source type generated by the server.
profile_metadata: Option<ProfileMetadata>Output only. Only populated in person.metadata.sources. Metadata about a source of type PROFILE.
type_: Option<String>The source type.
update_time: Option<DateTime<Utc>>Output only. Only populated in person.metadata.sources. Last update timestamp of this source.