pub struct ModifyContactGroupMembersResponse {
pub can_not_remove_last_contact_group_resource_names: Option<Vec<String>>,
pub not_found_resource_names: Option<Vec<String>>,
}Expand description
The response to a modify contact group members request.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- members modify contact groups (response)
Fields
can_not_remove_last_contact_group_resource_names: Option<Vec<String>>The contact people resource names that cannot be removed from their last contact group.
not_found_resource_names: Option<Vec<String>>The contact people resource names that were not found.